@@ -21,6 +21,13 @@ G_CONST_RETURN
 gchar      *glade_get_displayable_value           (GType          type, 
 						   const gchar   *value);
 
+gboolean    glade_displayable_value_is_disabled   (GType          type, 
+						   const gchar   *value);
+
+void        glade_displayable_value_set_disabled  (GType type,
+                                                   const gchar *value,
+                                                   gboolean disabled);
+
 G_CONST_RETURN 
 gchar      *glade_get_value_from_displayable      (GType          type, 
 						   const gchar   *displayabe);
