@@ -93,6 +93,7 @@ struct _GladeInspectorPrivate
   guint idle_complete;
   gboolean search_disabled;
   gchar *completion_text;
+  gchar *completion_text_fold;
 };
 
 static GParamSpec *properties[N_PROPERTIES];
@@ -201,21 +202,6 @@ glade_inspector_class_init (GladeInspectorClass *klass)
   g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 }
 
-static gboolean
-find_in_string_insensitive (const gchar *_haystack, const gchar *_needle)
-{
-  gboolean visible;
-  gchar *haystack = g_utf8_casefold (_haystack, -1);
-  gchar *needle = g_utf8_casefold (_needle, -1);
-
-  visible = strstr (haystack, needle) != NULL;
-
-  g_free (haystack);
-  g_free (needle);
-
-  return visible;
-}
-
 static gboolean
 glade_inspector_visible_func (GtkTreeModel *model,
                               GtkTreeIter  *parent,
@@ -242,13 +228,16 @@ glade_inspector_visible_func (GtkTreeModel *model,
 
   if (!retval)
     {
-      gchar *widget_name;
+      gchar *widget_name, *haystack;
 
       gtk_tree_model_get (model, parent, GLADE_PROJECT_MODEL_COLUMN_NAME,
                           &widget_name, -1);
 
-      retval = find_in_string_insensitive (widget_name, priv->completion_text);
+      haystack = g_utf8_casefold (widget_name, -1);
 
+      retval = strstr (haystack, priv->completion_text_fold) != NULL;
+
+      g_free (haystack);
       g_free (widget_name);
     }
 
@@ -281,7 +270,7 @@ typedef struct {
 
 static void
 reduce_string (gchar *str1,
-	       gchar *str2)
+	       const gchar *str2)
 {
   gint str1len = strlen (str1);
   gint i;
@@ -306,30 +295,35 @@ search_common_matches (GtkTreeModel    *model,
 		       GtkTreeIter     *iter,
 		       CommonMatchData *data)
 {
-  gchar *row_text = NULL;
+  GladeWidget *gwidget;
+  const gchar *name;
+  GObject *obj;
   gboolean match;
 
-  gtk_tree_model_get (model, iter, GLADE_PROJECT_MODEL_COLUMN_NAME, &row_text, -1);
+  gtk_tree_model_get (model, iter, GLADE_PROJECT_MODEL_COLUMN_OBJECT, &obj, -1);
+  gwidget = glade_widget_get_from_gobject (obj);
 
-  match = (strncmp (data->text, row_text, strlen (data->text)) == 0);
+  if (!glade_widget_has_name (gwidget))
+    {
+      g_object_unref (obj);
+      return FALSE;
+    }
+
+  name  = glade_widget_get_name (gwidget);
+  match = (strncmp (data->text, name, strlen (data->text)) == 0);
 
   if (match)
     {
       if (!data->first_match)
-	data->first_match = g_strdup (row_text);
+	data->first_match = g_strdup (name);
 
       if (data->common_text)
-	{
-	  reduce_string (data->common_text, row_text);
-
-	  g_free (row_text);
-	}
+        reduce_string (data->common_text, name);
       else
-	data->common_text = row_text;
+	data->common_text = g_strdup (name);
     }
-  else
-    g_free (row_text);
 
+  g_object_unref (obj);
   return FALSE;
 }
 
@@ -361,6 +355,17 @@ get_partial_match (GladeInspector *inspector,
   return data.common_text;
 }
 
+static void
+inspector_set_completion_text (GladeInspector *inspector, const gchar *text)
+{
+  GladeInspectorPrivate *priv = inspector->priv;
+
+  g_free (priv->completion_text);
+  priv->completion_text = g_strdup (text);
+  priv->completion_text_fold = text ? g_utf8_casefold (text, -1) : NULL;
+
+}
+
 static gboolean
 search_complete_idle (GladeInspector *inspector)
 {
@@ -373,8 +378,7 @@ search_complete_idle (GladeInspector *inspector)
 
   completed = get_partial_match (inspector, str, NULL);
   
-  g_free (priv->completion_text);
-  priv->completion_text = g_strdup (str);
+  inspector_set_completion_text (inspector, str);
 
   if (completed)
     {
@@ -424,13 +428,7 @@ search_entry_text_deleted_cb (GtkEditable    *editable,
 
   if (!priv->search_disabled)
     {
-      const gchar *str;
-
-      str = gtk_entry_get_text (GTK_ENTRY (priv->entry));
-
-      g_free (priv->completion_text);
-      priv->completion_text = g_strdup (str);
-
+      inspector_set_completion_text (inspector, gtk_entry_get_text (GTK_ENTRY (priv->entry)));
       glade_inspector_refilter (inspector);
     }
 }
@@ -454,8 +452,7 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
         }
       else /* Tab: Move cursor forward and refine the filter to include all text */
         {
-	  g_free (priv->completion_text);
-	  priv->completion_text = g_strdup (str);
+          inspector_set_completion_text (inspector, str);
 
           gtk_editable_set_position (GTK_EDITABLE (entry), -1);
           gtk_editable_select_region (GTK_EDITABLE (entry), -1, -1);
@@ -474,8 +471,7 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
         {
 	  GladeWidget *widget;
 
-	  g_free (priv->completion_text);
-	  priv->completion_text = full_match;
+          inspector_set_completion_text (inspector, full_match);
 	  g_free (name);
 
 	  g_signal_handlers_block_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
@@ -554,8 +550,7 @@ search_entry_focus_out_cb (GtkWidget      *entry,
 
   priv->search_disabled = TRUE;
 
-  g_free (priv->completion_text);
-  priv->completion_text = NULL;
+  inspector_set_completion_text (inspector, NULL);
 
   gtk_entry_set_text (GTK_ENTRY (priv->entry), "");
 
@@ -657,8 +652,10 @@ static void
 glade_inspector_finalize (GObject *object)
 {
   GladeInspector *inspector = GLADE_INSPECTOR (object);
+  GladeInspectorPrivate *priv = inspector->priv;
 
-  g_free (inspector->priv->completion_text);
+  g_free (priv->completion_text);
+  g_free (priv->completion_text_fold);
 
   G_OBJECT_CLASS (glade_inspector_parent_class)->finalize (object);
 }
@@ -861,6 +858,31 @@ glade_inspector_warning_cell_data_func (GtkTreeViewColumn *column,
   g_free (warning);
 }
 
+static void
+glade_inspector_name_cell_data_func (GtkTreeViewColumn *column,
+				     GtkCellRenderer   *renderer,
+				     GtkTreeModel      *model,
+				     GtkTreeIter       *iter,
+				     gpointer           data)
+{
+  GladeWidget *gwidget;
+  GObject *obj;
+
+  gtk_tree_model_get (model, iter,
+		      GLADE_PROJECT_MODEL_COLUMN_OBJECT, &obj,
+		      -1);
+
+  gwidget = glade_widget_get_from_gobject (obj);
+
+  g_object_set (renderer, "text", 
+		(glade_widget_has_name (gwidget)) ? 
+		  glade_widget_get_display_name (gwidget) : NULL,
+		NULL);
+
+  g_object_unref (obj);
+}
+
+
 static void
 glade_inspector_detail_cell_data_func (GtkTreeViewColumn *column,
 				       GtkCellRenderer   *renderer,
@@ -944,6 +966,9 @@ add_columns (GtkTreeView *view)
                                        renderer,
                                        "text", GLADE_PROJECT_MODEL_COLUMN_NAME,
                                        NULL);
+  gtk_tree_view_column_set_cell_data_func (column, renderer,
+					   glade_inspector_name_cell_data_func,
+					   NULL, NULL);
 
   /* Padding */
   renderer = gtk_cell_renderer_text_new ();
