@@ -45,7 +45,7 @@
 #include "glade-cursor.h"
 #include "glade-widget.h"
 #include "glade-app.h"
-#include "glade-adaptor-chooser.h"
+#include "glade-adaptor-chooser-widget.h"
 #include <math.h>
 
 #include "glade-dnd.h"
@@ -386,9 +386,9 @@ glade_placeholder_motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 }
 
 static void
-on_chooser_adaptor_selected (_GladeAdaptorChooser *chooser,
-                             GladeWidgetAdaptor  *adaptor,
-                             GladePlaceholder    *placeholder)
+on_chooser_adaptor_widget_selected (_GladeAdaptorChooserWidget *chooser,
+                                    GladeWidgetAdaptor         *adaptor,
+                                    GladePlaceholder           *placeholder)
 
 {
   glade_command_create (adaptor, glade_placeholder_get_parent (placeholder),
@@ -402,12 +402,13 @@ glade_placeholder_popover_new (GladePlaceholder *placeholder, GtkWidget *relativ
   GtkWidget *pop = gtk_popover_new (relative_to);
   GtkWidget *chooser;
 
-  chooser = _glade_adaptor_chooser_new (GLADE_ADAPTOR_CHOOSER_WIDGET |
-                                        GLADE_ADAPTOR_CHOOSER_SKIP_TOPLEVEL,
-                                        glade_placeholder_get_project (placeholder));
-
+  chooser = _glade_adaptor_chooser_widget_new (GLADE_ADAPTOR_CHOOSER_WIDGET_WIDGET |
+                                               GLADE_ADAPTOR_CHOOSER_WIDGET_SKIP_TOPLEVEL |
+                                               GLADE_ADAPTOR_CHOOSER_WIDGET_SKIP_DEPRECATED,
+                                               glade_placeholder_get_project (placeholder));
+  _glade_adaptor_chooser_widget_populate (GLADE_ADAPTOR_CHOOSER_WIDGET (chooser));
   g_signal_connect (chooser, "adaptor-selected",
-                    G_CALLBACK (on_chooser_adaptor_selected),
+                    G_CALLBACK (on_chooser_adaptor_widget_selected),
                     placeholder);
   gtk_popover_set_position (GTK_POPOVER (pop), GTK_POS_BOTTOM);
   gtk_container_add (GTK_CONTAINER (pop), chooser);
@@ -433,39 +434,43 @@ glade_placeholder_button_press (GtkWidget *widget, GdkEventButton *event)
   if (!gtk_widget_has_focus (widget))
     gtk_widget_grab_focus (widget);
 
-  if (event->button == 1)
+  if ((event->button == 1 || event->button == 2) &&
+       event->type == GDK_BUTTON_PRESS && adaptor != NULL)
     {
-      if (event->type == GDK_BUTTON_PRESS && adaptor != NULL)
+      GladeWidget *parent = glade_placeholder_get_parent (placeholder);
+
+      /* A widget type is selected in the palette.
+       * Add a new widget of that type.
+       */
+      glade_command_create (adaptor, parent, placeholder, project);
+
+      /* Let the user use the middle button to create more than one widget */
+      if (event->button != 2)
         {
-          GladeWidget *parent = glade_placeholder_get_parent (placeholder);
-
-          /* A widget type is selected in the palette.
-           * Add a new widget of that type.
-           */
-          glade_command_create (adaptor, parent, placeholder, project);
-
           glade_project_set_add_item (project, NULL);
-
           /* reset the cursor */
-          glade_cursor_set (project, event->window, GLADE_CURSOR_SELECTOR);
-          handled = TRUE;
+          glade_project_set_pointer_mode (project, GLADE_POINTER_SELECT);
         }
-      else if (event->type == GDK_2BUTTON_PRESS && adaptor == NULL)
-        {
-          GtkWidget *event_widget = gtk_get_event_widget ((GdkEvent*) event);
-          GladeWidget *toplevel = glade_widget_get_toplevel (glade_placeholder_get_parent (placeholder));
-          GtkWidget *parent = gtk_widget_get_parent (GTK_WIDGET (glade_widget_get_object (toplevel)));
-          GtkWidget *pop = glade_placeholder_popover_new (placeholder, parent);
-          GdkRectangle rect = {0, 0, 8, 8};
 
-          gtk_widget_translate_coordinates (event_widget, parent,
-                                            event->x, event->y,
-                                            &rect.x, &rect.y);
-          gtk_popover_set_pointing_to (GTK_POPOVER (pop), &rect);
-          gtk_widget_show (pop);
-          handled = TRUE;
-        }
+      handled = TRUE;
     }
+  else if (event->button == 1 &&
+           event->type == GDK_2BUTTON_PRESS &&
+           adaptor == NULL)
+    {
+      GtkWidget *event_widget = gtk_get_event_widget ((GdkEvent*) event);
+      GladeWidget *toplevel = glade_widget_get_toplevel (glade_placeholder_get_parent (placeholder));
+      GtkWidget *parent = gtk_widget_get_parent (GTK_WIDGET (glade_widget_get_object (toplevel)));
+      GtkWidget *pop = glade_placeholder_popover_new (placeholder, parent);
+      GdkRectangle rect = {0, 0, 8, 8};
+
+      gtk_widget_translate_coordinates (event_widget, parent,
+                                        event->x, event->y,
+                                        &rect.x, &rect.y);
+      gtk_popover_set_pointing_to (GTK_POPOVER (pop), &rect);
+      gtk_popover_popup (GTK_POPOVER (pop));
+      handled = TRUE;
+   }
 
   if (!handled && glade_popup_is_popup_event (event))
     {
