@@ -1,7 +1,22 @@
-/* This functions are based on gnome-print/libgpa/gpa-xml.c which were in turn 
- * based on gnumeric/xml-io.c
- */
-/* Authors:
+/*
+ * glade-xml-utils.c - This functions are based on gnome-print/libgpa/gpa-xml.c
+ * which were in turn based on gnumeric/xml-io.c
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+   *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ * Authors:
  *   Daniel Veillard <Daniel.Veillard@w3.org>
  *   Miguel de Icaza <miguel@gnu.org>
  *   Chema Celorio <chema@gnome.org>
@@ -26,6 +41,7 @@
 
 #include "glade-xml-utils.h"
 #include "glade-catalog.h"
+#include "glade-utils.h"
 
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -292,12 +308,6 @@ glade_xml_set_property (xmlNodePtr   node,
     xmlSetProp (node, BAD_CAST (name), BAD_CAST (value));
 }
 
-#define GLADE_TAG_TRUE   "True"
-#define GLADE_TAG_FALSE  "False"
-#define GLADE_TAG_TRUE2  "TRUE"
-#define GLADE_TAG_FALSE2 "FALSE"
-#define GLADE_TAG_TRUE3  "yes"
-#define GLADE_TAG_FALSE3 "no"
 /*
  * Get a String value for a node either carried as an attibute or as
  * the content of a child.
@@ -315,21 +325,8 @@ glade_xml_get_boolean (GladeXmlNode *node_in,
   if (value == NULL)
     return _default;
 
-  if (strcmp (value, GLADE_TAG_FALSE) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_FALSE2) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_FALSE3) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_TRUE) == 0)
-    ret = TRUE;
-  else if (strcmp (value, GLADE_TAG_TRUE2) == 0)
-    ret = TRUE;
-  else if (strcmp (value, GLADE_TAG_TRUE3) == 0)
-    ret = TRUE;
-  else
+  if (glade_utils_boolean_from_string (value, &ret))
     g_warning ("Boolean tag unrecognized *%s*\n", value);
-
   g_free (value);
 
   return ret;
@@ -352,21 +349,8 @@ glade_xml_get_property_boolean (GladeXmlNode *node_in,
   if (value == NULL)
     return _default;
 
-  if (strcmp (value, GLADE_TAG_FALSE) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_FALSE2) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_FALSE3) == 0)
-    ret = FALSE;
-  else if (strcmp (value, GLADE_TAG_TRUE) == 0)
-    ret = TRUE;
-  else if (strcmp (value, GLADE_TAG_TRUE2) == 0)
-    ret = TRUE;
-  else if (strcmp (value, GLADE_TAG_TRUE3) == 0)
-    ret = TRUE;
-  else
+  if (glade_utils_boolean_from_string (value, &ret))
     g_warning ("Boolean tag unrecognized *%s*\n", value);
-
   g_free (value);
 
   return ret;
@@ -427,18 +411,11 @@ glade_xml_node_set_property_boolean (GladeXmlNode *node_in,
   xmlNodePtr node = (xmlNodePtr) node_in;
 
   if (value)
-    glade_xml_set_property (node, name, GLADE_TAG_TRUE);
+    glade_xml_set_property (node, name, "True");
   else
-    glade_xml_set_property (node, name, GLADE_TAG_FALSE);
+    glade_xml_set_property (node, name, "False");
 }
 
-#undef GLADE_TAG_TRUE
-#undef GLADE_TAG_FALSE
-#undef GLADE_TAG_TRUE2
-#undef GLADE_TAG_FALSE2
-#undef GLADE_TAG_TRUE3
-#undef GLADE_TAG_FALSE3
-
 gchar *
 glade_xml_get_value_string_required (GladeXmlNode *node_in,
                                      const gchar  *name,
