@@ -344,16 +344,13 @@ glade_gtk_widget_write_atk_property (GladeProperty * property,
                                      GladeXmlContext * context,
                                      GladeXmlNode * node)
 {
-  GladeXmlNode *prop_node;
-  GladePropertyClass *pclass;
-  gchar *value;
+  gchar *value = glade_property_make_string (property);
 
-  glade_property_get (property, &value);
   if (value && value[0])
     {
-      pclass = glade_property_get_class (property);
+      GladePropertyClass *pclass = glade_property_get_class (property);
+      GladeXmlNode *prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_PROPERTY);
 
-      prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_PROPERTY);
       glade_xml_node_append_child (node, prop_node);
 
       glade_xml_node_set_property_string (prop_node,
@@ -376,6 +373,8 @@ glade_gtk_widget_write_atk_property (GladeProperty * property,
                                             GLADE_TAG_CONTEXT,
                                             glade_property_i18n_get_context (property));
     }
+
+  g_free (value);
 }
 
 static void
@@ -384,17 +383,23 @@ glade_gtk_widget_write_atk_properties (GladeWidget * widget,
                                        GladeXmlNode * node)
 {
   GladeXmlNode *child_node, *object_node;
-  GladeProperty *name_prop, *desc_prop;
+  GladeProperty *name_prop, *desc_prop, *role_prop;
 
   name_prop = glade_widget_get_property (widget, "AtkObject::accessible-name");
   desc_prop =
       glade_widget_get_property (widget, "AtkObject::accessible-description");
+  role_prop = glade_widget_get_property (widget, "AtkObject::accessible-role");
 
   /* Create internal child here if any of these properties are non-null */
   if (!glade_property_default (name_prop) ||
-      !glade_property_default (desc_prop))
+      !glade_property_default (desc_prop) ||
+      !glade_property_default (role_prop))
     {
-      gchar *atkname = g_strdup_printf ("%s-atkobject", glade_widget_get_name (widget));
+      const gchar *widget_name = glade_widget_get_name (widget);
+      gchar *atkname = NULL;
+
+      if (!g_str_has_prefix (widget_name, GLADE_UNNAMED_PREFIX))
+        atkname = g_strdup_printf ("%s-atkobject", widget_name);
 
       child_node = glade_xml_node_new (context, GLADE_XML_TAG_CHILD);
       glade_xml_node_append_child (node, child_node);
@@ -409,13 +414,16 @@ glade_gtk_widget_write_atk_properties (GladeWidget * widget,
       glade_xml_node_set_property_string (object_node,
                                           GLADE_XML_TAG_CLASS, "AtkObject");
 
-      glade_xml_node_set_property_string (object_node,
-                                          GLADE_XML_TAG_ID, atkname);
+      if (atkname)
+        glade_xml_node_set_property_string (object_node,
+                                            GLADE_XML_TAG_ID, atkname);
 
       if (!glade_property_default (name_prop))
         glade_gtk_widget_write_atk_property (name_prop, context, object_node);
       if (!glade_property_default (desc_prop))
         glade_gtk_widget_write_atk_property (desc_prop, context, object_node);
+      if (!glade_property_default (role_prop))
+        glade_gtk_widget_write_atk_property (role_prop, context, object_node);
 
       g_free (atkname);
     }
@@ -481,16 +489,12 @@ glade_gtk_widget_write_atk_action (GladeProperty * property,
                                    GladeXmlContext * context,
                                    GladeXmlNode * node)
 {
-  GladeXmlNode *prop_node;
-  GladePropertyClass *pclass;
-  gchar *value = NULL;
-
-  glade_property_get (property, &value);
+  gchar *value = glade_property_make_string (property);
 
   if (value && value[0])
     {
-      pclass = glade_property_get_class (property);
-      prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_ACTION);
+      GladePropertyClass *pclass = glade_property_get_class (property);
+      GladeXmlNode *prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_ACTION);
       glade_xml_node_append_child (node, prop_node);
 
       glade_xml_node_set_property_string (prop_node,
@@ -499,6 +503,8 @@ glade_gtk_widget_write_atk_action (GladeProperty * property,
       glade_xml_node_set_property_string (prop_node,
                                           GLADE_TAG_A11Y_DESC, value);
     }
+
+  g_free (value);
 }
 
 static void
@@ -881,6 +887,8 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
         new_type = GTK_TYPE_BOX;
       else if (strcmp (action, "paned") == 0)
         new_type = GTK_TYPE_PANED;
+      else if (strcmp (action, "stack") == 0)
+        new_type = GTK_TYPE_STACK;
 
       if (new_type)
         {
@@ -1004,14 +1012,35 @@ glade_gtk_widget_add2group_cb (GtkMenuItem * item, GladeWidget * gwidget)
       glade_widget_adaptor_get_by_type (GTK_TYPE_SIZE_GROUP);
   GList *widget_list = NULL, *new_list;
   GladeProperty *property;
+  const gchar *current_name;
+  const gchar *size_group_name = NULL;
+  gchar *widget_name;
+
+  /* Display "(unnamed)" for unnamed size groups */
+  if (group)
+    {
+      size_group_name = glade_widget_get_name (group);
+      if (g_str_has_prefix (size_group_name, GLADE_UNNAMED_PREFIX))
+	size_group_name = _("(unnamed)");
+    }
+
+  /* Ensure the widget has a name if it's going to be referred to by a size group */
+  current_name = glade_widget_get_name (gwidget);
+  if (g_str_has_prefix (current_name, GLADE_UNNAMED_PREFIX))
+    widget_name = glade_project_new_widget_name (glade_widget_get_project (gwidget), NULL,
+						 glade_widget_adaptor_get_generic_name (glade_widget_get_adaptor (gwidget)));
+  else
+    widget_name = g_strdup (current_name);
 
   if (group)
-    glade_command_push_group (_("Adding %s to Size Group %s"), 
-			      glade_widget_get_name (gwidget),
-                              glade_widget_get_name (group));
+    glade_command_push_group (_("Adding %s to Size Group %s"),
+			      widget_name,
+                              size_group_name);
   else
     glade_command_push_group (_("Adding %s to a new Size Group"),
-                              glade_widget_get_name (gwidget));
+                              widget_name);
+
+  glade_command_set_name (gwidget, widget_name);
 
   if (!group)
     /* Cant cancel a size group */
@@ -1027,6 +1056,7 @@ glade_gtk_widget_add2group_cb (GtkMenuItem * item, GladeWidget * gwidget)
   glade_command_set_property (property, new_list);
 
   g_list_free (new_list);
+  g_free (widget_name);
 
   glade_command_pop_group ();
 }
@@ -1044,13 +1074,19 @@ glade_gtk_widget_action_submenu (GladeWidgetAdaptor * adaptor,
       GtkWidget *menu = gtk_menu_new ();
       GtkWidget *separator, *item;
       GladeWidget *group;
+      const gchar *size_group_name;
 
       if ((groups = list_sizegroups (gwidget)) != NULL)
         {
           for (list = groups; list; list = list->next)
             {
               group = list->data;
-              item = gtk_menu_item_new_with_label (glade_widget_get_name (group));
+
+	      size_group_name = glade_widget_get_name (group);
+	      if (g_str_has_prefix (size_group_name, GLADE_UNNAMED_PREFIX))
+		size_group_name = _("(unnamed)");
+
+	      item = gtk_menu_item_new_with_label (size_group_name);
 
               g_object_set_data (G_OBJECT (item), "glade-group-widget", group);
               g_signal_connect (G_OBJECT (item), "activate",
