@@ -61,45 +61,40 @@ struct _GladeLabelEditorPrivate
 static GladeEditableIface *parent_editable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GladeLabelEditor, glade_label_editor, GLADE_TYPE_EDITOR_SKELETON,
+                         G_ADD_PRIVATE (GladeLabelEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
                                                 glade_label_editor_editable_init));
 
 static void
 glade_label_editor_class_init (GladeLabelEditorClass * klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   widget_class->grab_focus = glade_label_editor_grab_focus;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/gladegtk/glade-label-editor.ui");
 
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, embed);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, attributes_radio);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, markup_radio);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, pattern_radio);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, wrap_free_label);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, wrap_free_radio);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, single_radio);
-  gtk_widget_class_bind_child (widget_class, GladeLabelEditorPrivate, wrap_mode_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, embed);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, attributes_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, markup_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, pattern_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, wrap_free_label);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, wrap_free_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, single_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeLabelEditor, wrap_mode_radio);
 
-  gtk_widget_class_bind_callback (widget_class, attributes_toggled);
-  gtk_widget_class_bind_callback (widget_class, markup_toggled);
-  gtk_widget_class_bind_callback (widget_class, pattern_toggled);
-  gtk_widget_class_bind_callback (widget_class, wrap_free_toggled);
-  gtk_widget_class_bind_callback (widget_class, single_toggled);
-  gtk_widget_class_bind_callback (widget_class, wrap_mode_toggled);
-
-  g_type_class_add_private (object_class, sizeof (GladeLabelEditorPrivate));  
+  gtk_widget_class_bind_template_callback (widget_class, attributes_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, markup_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, pattern_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, wrap_free_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, single_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, wrap_mode_toggled);
 }
 
 static void
 glade_label_editor_init (GladeLabelEditor * self)
 {
-  self->priv = 
-    G_TYPE_INSTANCE_GET_PRIVATE (self,
-				 GLADE_TYPE_LABEL_EDITOR,
-				 GladeLabelEditorPrivate);
+  self->priv = glade_label_editor_get_instance_private (self);
 
   gtk_widget_init_template (GTK_WIDGET (self));
 }
