@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2001 Ximian, Inc.
  * Copyright (C) 2007 Vincent Geddes.
- * Copyright (C) 2012-2017 Juan Pablo Ugarte.
+ * Copyright (C) 2012-2018 Juan Pablo Ugarte.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -72,6 +72,9 @@
 #define CONFIG_KEY_AUTOSAVE         "autosave"
 #define CONFIG_KEY_AUTOSAVE_SECONDS "autosave-seconds"
 
+#define CONFIG_INTRO_GROUP          "Intro"
+#define CONFIG_INTRO_DONE           "intro-done"
+
 #define GLADE_WINDOW_ACTIVE_VIEW(w) ((GladeDesignView *) gtk_stack_get_visible_child (w->priv->view_stack))
 
 struct _GladeWindowPrivate
@@ -88,6 +91,7 @@ struct _GladeWindowPrivate
 
   GtkWidget *start_page;
   GtkLabel  *version_label;
+  GtkWidget *intro_button;
 
   GladeAdaptorChooser *adaptor_chooser;
   GtkStack *inspectors_stack;           /* Cached per project inspectors */
@@ -221,7 +225,7 @@ activate_action (GtkToolButton *toolbutton, GladeWidgetAction *action)
   if ((widget = g_object_get_data (G_OBJECT (toolbutton), "glade-widget")))
     glade_widget_adaptor_action_activate (glade_widget_get_adaptor (widget),
                                           glade_widget_get_object (widget), 
-					  aclass->path);
+                                          aclass->path);
 }
 
 static void
@@ -272,7 +276,6 @@ add_actions (GladeWindow *window, GladeWidget *widget, GList *actions)
     {
       GladeWidgetAction *action = l->data;
       GWActionClass     *aclass = glade_widget_action_get_class (action);
-      GtkWidget         *image;
 
       if (!aclass->important || !glade_widget_action_get_visible (action))
         continue;
@@ -283,9 +286,10 @@ add_actions (GladeWindow *window, GladeWidget *widget, GList *actions)
           continue;
         }
 
-      image = gtk_image_new_from_icon_name ((aclass->stock) ? aclass->stock : "system-run",
-                                            GTK_ICON_SIZE_LARGE_TOOLBAR);
-      item = gtk_tool_button_new (image, NULL);
+      item = gtk_tool_button_new (NULL, aclass->label);
+      gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item),
+                                     (aclass->stock) ? aclass->stock : "system-run");
+
       if (aclass->label)
         gtk_widget_set_tooltip_text (GTK_WIDGET (item), aclass->label);
 
@@ -300,7 +304,7 @@ add_actions (GladeWindow *window, GladeWidget *widget, GList *actions)
                              action, action_disconnect, 0);
 
       gtk_widget_set_sensitive (GTK_WIDGET (item), 
-				glade_widget_action_get_sensitive (action));
+                                glade_widget_action_get_sensitive (action));
 
       g_signal_connect (action, "notify::sensitive",
                         G_CALLBACK (activate_action), GTK_WIDGET (item));
@@ -481,13 +485,13 @@ autosave_project (gpointer data)
 
   if (glade_project_autosave (project, NULL))
     glade_util_flash_message (window->priv->statusbar,
-			      window->priv->statusbar_actions_context_id,
-			      _("Autosaving '%s'"), display_name);
+                              window->priv->statusbar_actions_context_id,
+                              _("Autosaving '%s'"), display_name);
   else
     /* This is problematic, should we be more intrusive and popup a dialog ? */
     glade_util_flash_message (window->priv->statusbar,
-			      window->priv->statusbar_actions_context_id,
-			      _("Error autosaving '%s'"), display_name);
+                              window->priv->statusbar_actions_context_id,
+                              _("Error autosaving '%s'"), display_name);
 
   g_free (display_name);
 
@@ -497,19 +501,18 @@ autosave_project (gpointer data)
 }
 
 static void
-project_queue_autosave (GladeWindow  *window,
-			GladeProject *project)
+project_queue_autosave (GladeWindow *window, GladeProject *project)
 {
   if (glade_project_get_path (project) != NULL &&
       glade_project_get_modified (project) &&
       glade_preferences_autosave (window->priv->preferences))
     {
       guint autosave_id =
-	g_timeout_add_seconds (glade_preferences_autosave_seconds (window->priv->preferences),
-			       autosave_project, project);
+        g_timeout_add_seconds (glade_preferences_autosave_seconds (window->priv->preferences),
+                               autosave_project, project);
 
       g_object_set_data_full (G_OBJECT (project), "glade-autosave-id",
-			      GUINT_TO_POINTER (autosave_id), cancel_autosave);
+                              GUINT_TO_POINTER (autosave_id), cancel_autosave);
     }
   else
       g_object_set_data (G_OBJECT (project), "glade-autosave-id", NULL);
@@ -762,12 +765,12 @@ do_save (GladeWindow *window, GladeProject *project, const gchar *path)
       !glade_project_backup (project, path, NULL))
     {
       if (!glade_util_ui_message (GTK_WIDGET (window),
-				  GLADE_UI_ARE_YOU_SURE, NULL,
-				  _("Failed to backup existing file, continue saving?")))
-	{
-	  g_free (display_path);
-	  return FALSE;
-	}
+                                  GLADE_UI_ARE_YOU_SURE, NULL,
+                                  _("Failed to backup existing file, continue saving?")))
+        {
+          g_free (display_path);
+          return FALSE;
+        }
     }
 
   if (glade_preferences_warn_versioning (window->priv->preferences))
@@ -781,8 +784,8 @@ do_save (GladeWindow *window, GladeProject *project, const gchar *path)
     {
       if (error)
         {
-	  /* Reset path so future saves will prompt the file chooser */
-	  glade_project_reset_path (project);
+          /* Reset path so future saves will prompt the file chooser */
+          glade_project_reset_path (project);
 
           glade_util_ui_message (GTK_WIDGET (window), GLADE_UI_ERROR, NULL,
                                  _("Failed to save %s: %s"),
@@ -818,42 +821,42 @@ save (GladeWindow *window, GladeProject *project, const gchar *path)
       mtime = glade_util_get_file_mtime (glade_project_get_path (project), NULL);
 
       if (mtime > glade_project_get_file_mtime (project))
-	{
+        {
 
-	  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-					   GTK_DIALOG_MODAL,
-					   GTK_MESSAGE_WARNING,
-					   GTK_BUTTONS_NONE,
-					   _("The file %s has been modified since reading it"),
-					   glade_project_get_path (project));
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                           GTK_DIALOG_MODAL,
+                                           GTK_MESSAGE_WARNING,
+                                           GTK_BUTTONS_NONE,
+                                           _("The file %s has been modified since reading it"),
+                                           glade_project_get_path (project));
 
-	  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						    _("If you save it, all the external changes could be lost. "
-						      "Save it anyway?"));
+          gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                    _("If you save it, all the external changes could be lost. "
+                                                    "Save it anyway?"));
 
-	  gtk_window_set_title (GTK_WINDOW (dialog), "");
+          gtk_window_set_title (GTK_WINDOW (dialog), "");
 
-	  button = gtk_button_new_with_mnemonic (_("_Save Anyway"));
-	  gtk_button_set_image (GTK_BUTTON (button),
-				gtk_image_new_from_icon_name ("document-save",
-                                                              GTK_ICON_SIZE_BUTTON));
-	  gtk_widget_show (button);
+          button = gtk_button_new_with_mnemonic (_("_Save Anyway"));
+          gtk_button_set_image (GTK_BUTTON (button),
+                                gtk_image_new_from_icon_name ("document-save",
+                                                                      GTK_ICON_SIZE_BUTTON));
+          gtk_widget_show (button);
 
-	  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
-					GTK_RESPONSE_ACCEPT);
-	  gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't Save"),
-				 GTK_RESPONSE_REJECT);
+          gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
+                                        GTK_RESPONSE_ACCEPT);
+          gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't Save"),
+                                 GTK_RESPONSE_REJECT);
 
-	  gtk_dialog_set_default_response (GTK_DIALOG (dialog),
-					   GTK_RESPONSE_REJECT);
+          gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+                                           GTK_RESPONSE_REJECT);
 
-	  response = gtk_dialog_run (GTK_DIALOG (dialog));
+          response = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	  gtk_widget_destroy (dialog);
+          gtk_widget_destroy (dialog);
 
-	  if (response == GTK_RESPONSE_REJECT)
-	    return;
-	}
+          if (response == GTK_RESPONSE_REJECT)
+            return;
+      }
     }
 
   /* Interestingly; we cannot use `path' after glade_project_reset_path
@@ -973,8 +976,8 @@ save_as (GladeWindow *window)
                                        path);
 
       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						_("You do not have the permissions "
-						  "necessary to save the file."));
+                                                _("You do not have the permissions "
+                                                  "necessary to save the file."));
 
       gtk_window_set_title (GTK_WINDOW (dialog), "");
 
@@ -1528,7 +1531,7 @@ drag_data_received (GtkWidget *widget,
           g_warning ("Could not convert uri to local path: %s", error->message);
 
           g_error_free (error);
-	}
+        }
       g_free (path);
     }
   g_strfreev (uris);
@@ -2036,6 +2039,10 @@ glade_window_config_load (GladeWindow *window)
   /* Paned positions */
   load_paned_position (config, window->priv->left_paned, "left_pane", 200);
   load_paned_position (config, window->priv->center_paned, "center_pane", 400);
+
+  /* Intro button */
+  if (g_key_file_get_boolean (config, CONFIG_INTRO_GROUP, CONFIG_INTRO_DONE, FALSE))
+    gtk_widget_hide (window->priv->intro_button);
 }
 
 static void
@@ -2104,6 +2111,7 @@ static void
 on_intro_action_activate (GSimpleAction *action, GVariant *p, gpointer data)
 {
   GladeWindow *window = data;
+  gtk_widget_show (window->priv->intro_button);
   glade_intro_play (window->priv->intro);
 }
 
@@ -2272,6 +2280,14 @@ on_intro_hide_node (GladeIntro  *intro,
 
       g_list_free (children);
     }
+  else if (!g_strcmp0 (node, "done"))
+    {
+      gtk_widget_hide (window->priv->intro_button);
+      g_key_file_set_boolean (glade_app_get_config (),
+                              CONFIG_INTRO_GROUP,
+                              CONFIG_INTRO_DONE,
+                              TRUE);
+    }
   else if (!g_strcmp0 (node, "add-project") ||
            !g_strcmp0 (node, "add-window") ||
            !g_strcmp0 (node, "add-grid") ||
@@ -2285,7 +2301,7 @@ static void
 glade_window_populate_intro (GladeWindow *window)
 {
   ADD_NODE (NULL, "intro-button",  BOTTOM, 5, _("Hello, I will show you what's new in Glade"));
-  ADD_NODE (NULL, "headerbar",     BOTTOM, 6, _("The menubar and toolbar where merged in the headerbar"));
+  ADD_NODE (NULL, "headerbar",     BOTTOM, 6, _("The menubar and toolbar were merged in the headerbar"));
 
   ADD_NODE (NULL, "open-button",   BOTTOM, 3, _("You can open a project"));
   ADD_NODE (NULL, "recent-button", BOTTOM, 2, _("find recently used"));
@@ -2297,30 +2313,30 @@ glade_window_populate_intro (GladeWindow *window)
   ADD_NODE (NULL, "redo-button",       BOTTOM, 2, _("Redo"));
   ADD_NODE (NULL, "project-switcher",  BOTTOM, 3, _("Project switcher"));
 
-  ADD_NODE (NULL, "save-button",       BOTTOM, 4, _("and Save button are directly accesible in the headerbar"));
+  ADD_NODE (NULL, "save-button",       BOTTOM, 4, _("and Save button are directly accessible in the headerbar"));
   ADD_NODE (NULL, "save-as-button",    BOTTOM, 2, _("just like Save As"));
   ADD_NODE (NULL, "properties-button", BOTTOM, 2, _("project properties"));
   ADD_NODE (NULL, "menu-button",       BOTTOM, 3, _("and less commonly used actions"));
 
-  ADD_NODE (NULL, "inspector", CENTER, 3, _("The object inspector took the palette place"));
+  ADD_NODE (NULL, "inspector", CENTER, 3, _("The object inspector took the palette's place"));
   ADD_NODE (NULL, "editor",    CENTER, 3, _("To free up space for the property editor"));
 
   ADD_NODE (NULL,      "adaptor-chooser",       BOTTOM, 4, _("The palette was replaced with a new object chooser"));
   ADD_NODE ("search",  "adaptor-search-button", RIGHT,  3, _("Where you can search all supported classes"));
-  ADD_NODE ("gtk",     "adaptor-gtk-buttonbox", BOTTOM, 2.5, _("investigate Gtk object groups"));
+  ADD_NODE ("gtk",     "adaptor-gtk-buttonbox", BOTTOM, 2.5, _("investigate GTK+ object groups"));
   ADD_NODE ("others",  "adaptor-others-button", RIGHT,  4, _("and find classes introduced by other libraries"));
 
-  ADD_NODE (NULL, "intro-button", BOTTOM, 6, _("OK, now  we are done with the overview let start with the new workflow"));
+  ADD_NODE (NULL, "intro-button", BOTTOM, 6, _("OK, now that we are done with the overview, let's start with the new workflow"));
 
   ADD_NODE ("add-project", "intro-button", BOTTOM, 4, _("First of all, create a new project"));
-  ADD_NODE ("add-window",  "intro-button", BOTTOM, 6, _("Ok, now add a GtkWindow using the new widget chooser or by double clicking on the workspace"));
-  ADD_NODE (NULL,          "intro-button", BOTTOM, 2, _("Excelent!"));
-  ADD_NODE (NULL,          "intro-button", BOTTOM, 5, _("BTW Did you know you can double click on any placeholder to create widgets?"));
+  ADD_NODE ("add-window",  "intro-button", BOTTOM, 6, _("OK, now add a GtkWindow using the new widget chooser or by double clicking on the workspace"));
+  ADD_NODE (NULL,          "intro-button", BOTTOM, 2, _("Excellent!"));
+  ADD_NODE (NULL,          "intro-button", BOTTOM, 5, _("BTW, did you know you can double click on any placeholder to create widgets?"));
   ADD_NODE ("add-grid",    "intro-button", BOTTOM, 3, _("Try adding a grid"));
   ADD_NODE ("add-button",  "intro-button", BOTTOM, 3, _("and a button"));
 
-  ADD_NODE (NULL, "intro-button",  BOTTOM, 3, _("Quite easy! isn't it?"));
-  ADD_NODE (NULL, "intro-button",  BOTTOM, 2, _("Enjoy!"));
+  ADD_NODE (NULL,   "intro-button",  BOTTOM, 3, _("Quite easy! Isn't it?"));
+  ADD_NODE ("done", "intro-button",  BOTTOM, 2, _("Enjoy!"));
 
   g_signal_connect (window->priv->intro, "show-node",
                     G_CALLBACK (on_intro_show_node),
@@ -2468,6 +2484,7 @@ glade_window_class_init (GladeWindowClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, about_dialog);
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, start_page);
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, version_label);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, intro_button);
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, center_paned);
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, left_paned);
   gtk_widget_class_bind_template_child_private (widget_class, GladeWindow, open_button_box);
